==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadGroupSpecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WorkloadGroupSpecFluentImpl<A extends WorkloadGroupSpecFluent<A>> extends BaseFluent<A> implements WorkloadGroupSpecFluent<A>{
  public WorkloadGroupSpecFluentImpl() {
  }
  public WorkloadGroupSpecFluentImpl(WorkloadGroupSpec instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withProbe(instance.getProbe()); 
    this.withTemplate(instance.getTemplate()); 
  }
  private WorkloadGroupObjectMetaBuilder metadata;
  private ReadinessProbeBuilder probe;
  private WorkloadEntrySpecBuilder template;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadGroupObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public WorkloadGroupObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(WorkloadGroupObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new WorkloadGroupObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public WorkloadGroupSpecFluent.MetadataNested<A> withNewMetadata() {
    return new WorkloadGroupSpecFluentImpl.MetadataNestedImpl();
  }
  public WorkloadGroupSpecFluent.MetadataNested<A> withNewMetadataLike(WorkloadGroupObjectMeta item) {
    return new WorkloadGroupSpecFluentImpl.MetadataNestedImpl(item);
  }
  public WorkloadGroupSpecFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public WorkloadGroupSpecFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new WorkloadGroupObjectMetaBuilder().build());
  }
  public WorkloadGroupSpecFluent.MetadataNested<A> editOrNewMetadataLike(WorkloadGroupObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProbe instead.
   * @return The buildable object.
   */
  @Deprecated
  public ReadinessProbe getProbe() {
    return this.probe!=null ?this.probe.build():null;
  }
  public ReadinessProbe buildProbe() {
    return this.probe!=null ?this.probe.build():null;
  }
  public A withProbe(ReadinessProbe probe) {
    _visitables.get("probe").remove(this.probe);
    if (probe!=null){ this.probe= new ReadinessProbeBuilder(probe); _visitables.get("probe").add(this.probe);} else { this.probe = null; _visitables.get("probe").remove(this.probe); } return (A) this;
  }
  public Boolean hasProbe() {
    return this.probe != null;
  }
  public WorkloadGroupSpecFluent.ProbeNested<A> withNewProbe() {
    return new WorkloadGroupSpecFluentImpl.ProbeNestedImpl();
  }
  public WorkloadGroupSpecFluent.ProbeNested<A> withNewProbeLike(ReadinessProbe item) {
    return new WorkloadGroupSpecFluentImpl.ProbeNestedImpl(item);
  }
  public WorkloadGroupSpecFluent.ProbeNested<A> editProbe() {
    return withNewProbeLike(getProbe());
  }
  public WorkloadGroupSpecFluent.ProbeNested<A> editOrNewProbe() {
    return withNewProbeLike(getProbe() != null ? getProbe(): new ReadinessProbeBuilder().build());
  }
  public WorkloadGroupSpecFluent.ProbeNested<A> editOrNewProbeLike(ReadinessProbe item) {
    return withNewProbeLike(getProbe() != null ? getProbe(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadEntrySpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public WorkloadEntrySpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(WorkloadEntrySpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new WorkloadEntrySpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public WorkloadGroupSpecFluent.TemplateNested<A> withNewTemplate() {
    return new WorkloadGroupSpecFluentImpl.TemplateNestedImpl();
  }
  public WorkloadGroupSpecFluent.TemplateNested<A> withNewTemplateLike(WorkloadEntrySpec item) {
    return new WorkloadGroupSpecFluentImpl.TemplateNestedImpl(item);
  }
  public WorkloadGroupSpecFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public WorkloadGroupSpecFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new WorkloadEntrySpecBuilder().build());
  }
  public WorkloadGroupSpecFluent.TemplateNested<A> editOrNewTemplateLike(WorkloadEntrySpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WorkloadGroupSpecFluentImpl that = (WorkloadGroupSpecFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (probe != null ? !probe.equals(that.probe) :that.probe != null) return false;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  probe,  template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (probe != null) { sb.append("probe:"); sb.append(probe + ","); }
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends WorkloadGroupObjectMetaFluentImpl<WorkloadGroupSpecFluent.MetadataNested<N>> implements WorkloadGroupSpecFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(WorkloadGroupObjectMeta item) {
      this.builder = new WorkloadGroupObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new WorkloadGroupObjectMetaBuilder(this);
    }
    WorkloadGroupObjectMetaBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class ProbeNestedImpl<N> extends ReadinessProbeFluentImpl<WorkloadGroupSpecFluent.ProbeNested<N>> implements WorkloadGroupSpecFluent.ProbeNested<N>,Nested<N>{
    ProbeNestedImpl(ReadinessProbe item) {
      this.builder = new ReadinessProbeBuilder(this, item);
    }
    ProbeNestedImpl() {
      this.builder = new ReadinessProbeBuilder(this);
    }
    ReadinessProbeBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withProbe(builder.build());
    }
    public N endProbe() {
      return and();
    }
    
  }
  class TemplateNestedImpl<N> extends WorkloadEntrySpecFluentImpl<WorkloadGroupSpecFluent.TemplateNested<N>> implements WorkloadGroupSpecFluent.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(WorkloadEntrySpec item) {
      this.builder = new WorkloadEntrySpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new WorkloadEntrySpecBuilder(this);
    }
    WorkloadEntrySpecBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadGroupSpecFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WorkloadGroupSpecFluentImpl<A extends WorkloadGroupSpecFluent<A>> extends BaseFluent<A> implements WorkloadGroupSpecFluent<A>{
  public WorkloadGroupSpecFluentImpl() {
  }
  public WorkloadGroupSpecFluentImpl(WorkloadGroupSpec instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withProbe(instance.getProbe());
      this.withTemplate(instance.getTemplate());
    }
  }
  private WorkloadGroupObjectMetaBuilder metadata;
  private ReadinessProbeBuilder probe;
  private WorkloadEntrySpecBuilder template;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadGroupObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public WorkloadGroupObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(WorkloadGroupObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new WorkloadGroupObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public WorkloadGroupSpecFluentImpl.MetadataNested<A> withNewMetadata() {
    return new WorkloadGroupSpecFluentImpl.MetadataNestedImpl();
  }
  public WorkloadGroupSpecFluentImpl.MetadataNested<A> withNewMetadataLike(WorkloadGroupObjectMeta item) {
    return new WorkloadGroupSpecFluentImpl.MetadataNestedImpl(item);
  }
  public WorkloadGroupSpecFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public WorkloadGroupSpecFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new WorkloadGroupObjectMetaBuilder().build());
  }
  public WorkloadGroupSpecFluentImpl.MetadataNested<A> editOrNewMetadataLike(WorkloadGroupObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildProbe instead.
   * @return The buildable object.
   */
  @Deprecated
  public ReadinessProbe getProbe() {
    return this.probe!=null ?this.probe.build():null;
  }
  public ReadinessProbe buildProbe() {
    return this.probe!=null ?this.probe.build():null;
  }
  public A withProbe(ReadinessProbe probe) {
    _visitables.get("probe").remove(this.probe);
    if (probe!=null){ this.probe= new ReadinessProbeBuilder(probe); _visitables.get("probe").add(this.probe);} else { this.probe = null; _visitables.get("probe").remove(this.probe); } return (A) this;
  }
  public Boolean hasProbe() {
    return this.probe != null;
  }
  public WorkloadGroupSpecFluentImpl.ProbeNested<A> withNewProbe() {
    return new WorkloadGroupSpecFluentImpl.ProbeNestedImpl();
  }
  public WorkloadGroupSpecFluentImpl.ProbeNested<A> withNewProbeLike(ReadinessProbe item) {
    return new WorkloadGroupSpecFluentImpl.ProbeNestedImpl(item);
  }
  public WorkloadGroupSpecFluentImpl.ProbeNested<A> editProbe() {
    return withNewProbeLike(getProbe());
  }
  public WorkloadGroupSpecFluentImpl.ProbeNested<A> editOrNewProbe() {
    return withNewProbeLike(getProbe() != null ? getProbe(): new ReadinessProbeBuilder().build());
  }
  public WorkloadGroupSpecFluentImpl.ProbeNested<A> editOrNewProbeLike(ReadinessProbe item) {
    return withNewProbeLike(getProbe() != null ? getProbe(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadEntrySpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public WorkloadEntrySpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(WorkloadEntrySpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new WorkloadEntrySpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public WorkloadGroupSpecFluentImpl.TemplateNested<A> withNewTemplate() {
    return new WorkloadGroupSpecFluentImpl.TemplateNestedImpl();
  }
  public WorkloadGroupSpecFluentImpl.TemplateNested<A> withNewTemplateLike(WorkloadEntrySpec item) {
    return new WorkloadGroupSpecFluentImpl.TemplateNestedImpl(item);
  }
  public WorkloadGroupSpecFluentImpl.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public WorkloadGroupSpecFluentImpl.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new WorkloadEntrySpecBuilder().build());
  }
  public WorkloadGroupSpecFluentImpl.TemplateNested<A> editOrNewTemplateLike(WorkloadEntrySpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadGroupSpecFluentImpl that = (WorkloadGroupSpecFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(probe, that.probe)) return false;

    if (!java.util.Objects.equals(template, that.template)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  probe,  template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (probe != null) { sb.append("probe:"); sb.append(probe + ","); }
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends WorkloadGroupObjectMetaFluentImpl<WorkloadGroupSpecFluentImpl.MetadataNested<N>> implements WorkloadGroupSpecFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(WorkloadGroupObjectMeta item) {
      this.builder = new WorkloadGroupObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new WorkloadGroupObjectMetaBuilder(this);
    }
    WorkloadGroupObjectMetaBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class ProbeNestedImpl<N> extends ReadinessProbeFluentImpl<WorkloadGroupSpecFluentImpl.ProbeNested<N>> implements WorkloadGroupSpecFluentImpl.ProbeNested<N>,Nested<N>{
    ProbeNestedImpl(ReadinessProbe item) {
      this.builder = new ReadinessProbeBuilder(this, item);
    }
    ProbeNestedImpl() {
      this.builder = new ReadinessProbeBuilder(this);
    }
    ReadinessProbeBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withProbe(builder.build());
    }
    public N endProbe() {
      return and();
    }
    
  }
  class TemplateNestedImpl<N> extends WorkloadEntrySpecFluentImpl<WorkloadGroupSpecFluentImpl.TemplateNested<N>> implements WorkloadGroupSpecFluentImpl.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(WorkloadEntrySpec item) {
      this.builder = new WorkloadEntrySpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new WorkloadEntrySpecBuilder(this);
    }
    WorkloadEntrySpecBuilder builder;
    public N and() {
      return (N) WorkloadGroupSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
